scxpand.core.inference\_results
===============================

.. automodule:: scxpand.core.inference_results

   
   .. rubric:: Classes

   .. autosummary::
   
      InferenceResults
      ModelInfo
   